=========
Tutorials
=========

To start using the `PIconnect` package a number of short tutorials are
available. It is recommended to start with the *Basics* tutorials,
which cover the connections to the different PI Systems.

Basics
------

.. toctree::
   tutorials/piserver
   tutorials/piaf

Data extraction
---------------

.. toctree::
   tutorials/recorded_values
   tutorials/interpolated_values
   tutorials/summaries
   tutorials/timezones
   tutorials/event_frames


Data manipulation
-----------------

.. toctree::
   tutorials/update_value
